@@ -27,6 +27,7 @@ import string
 import struct
 import logging
 import encrypt_salsa20
+import encrypt_rc4_md5
 
 
 def random_string(length):
@@ -60,8 +61,8 @@ def init_table(key, method=None):
         try:
             __import__('M2Crypto')
         except ImportError:
-            logging.error('M2Crypto is required to use encryption other than '
-                          'default method')
+            logging.error(('M2Crypto is required to use %s, please run'
+                           ' `apt-get install python-m2crypto`') % method)
             sys.exit(1)
     if not method:
         if key in cached_tables:
@@ -115,6 +116,7 @@ method_supported = {
     'idea-cfb': (16, 8),
     'rc2-cfb': (16, 8),
     'rc4': (16, 0),
+    'rc4-md5': (16, 16),
     'seed-cfb': (16, 16),
     'salsa20-ctr': (32, 8),
 }
@@ -154,14 +156,17 @@ class Encryptor(object):
                 iv = iv_
             iv = iv[:m[1]]
             if op == 1:
-                self.cipher_iv = iv[:m[1]]  # this iv is for cipher not decipher
-            if method != 'salsa20-ctr':
+                # this iv is for cipher not decipher
+                self.cipher_iv = iv[:m[1]]
+            if method == 'salsa20-ctr':
+                return encrypt_salsa20.Salsa20Cipher(method, key, iv, op)
+            elif method == 'rc4-md5':
+                return encrypt_rc4_md5.create_cipher(method, key, iv, op)
+            else:
                 import M2Crypto.EVP
                 return M2Crypto.EVP.Cipher(method.replace('-', '_'), key, iv,
                                            op, key_as_bytes=0, d='md5',
                                            salt=None, i=1, padding=1)
-            else:
-                return encrypt_salsa20.Salsa20Cipher(method, key, iv, op)
 
         logging.error('method %s not supported' % method)
         sys.exit(1)
@@ -216,11 +221,13 @@ def encrypt_all(password, method, op, data):
         else:
             iv = data[:iv_len]
             data = data[iv_len:]
-        if method != 'salsa20-ctr':
+        if method == 'salsa20-ctr':
+            cipher = encrypt_salsa20.Salsa20Cipher(method, key, iv, op)
+        elif method == 'rc4-md5':
+            cipher = encrypt_rc4_md5.create_cipher(method, key, iv, op)
+        else:
             cipher = M2Crypto.EVP.Cipher(method.replace('-', '_'), key, iv,
                                          op, key_as_bytes=0, d='md5',
                                          salt=None, i=1, padding=1)
-        else:
-            cipher = encrypt_salsa20.Salsa20Cipher(method, key, iv, op)
         result.append(cipher.update(data))
         return ''.join(result)
